==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/complex/CustomSubjectAlternativeName.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

import odata.msgraph.client.beta.enums.SubjectAlternativeNameType;


/**
 * <i>“Custom Subject Alternative Name definition”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "sanType", 
    "name"})
@JsonInclude(Include.NON_NULL)
public class CustomSubjectAlternativeName implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFields unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("sanType")
    protected SubjectAlternativeNameType sanType;

    @JsonProperty("name")
    protected String name;

    protected CustomSubjectAlternativeName() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.customSubjectAlternativeName";
    }

    /**
     * <i>“Custom SAN Type.”</i>
     * 
     * @return property sanType
     */
    @Property(name="sanType")
    @JsonIgnore
    public Optional<SubjectAlternativeNameType> getSanType() {
        return Optional.ofNullable(sanType);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code sanType} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“Custom SAN Type.”</i>
     * 
     * @param sanType
     *            new value of {@code sanType} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code sanType} field changed
     */
    public CustomSubjectAlternativeName withSanType(SubjectAlternativeNameType sanType) {
        CustomSubjectAlternativeName _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.customSubjectAlternativeName");
        _x.sanType = sanType;
        return _x;
    }

    /**
     * <i>“Custom SAN Name”</i>
     * 
     * @return property name
     */
    @Property(name="name")
    @JsonIgnore
    public Optional<String> getName() {
        return Optional.ofNullable(name);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code name} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“Custom SAN Name”</i>
     * 
     * @param name
     *            new value of {@code name} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code name} field changed
     */
    public CustomSubjectAlternativeName withName(String name) {
        CustomSubjectAlternativeName _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.customSubjectAlternativeName");
        _x.name = name;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private SubjectAlternativeNameType sanType;
        private String name;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        /**
         * <i>“Custom SAN Type.”</i>
         * 
         * @param sanType
         *            value of {@code sanType} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder sanType(SubjectAlternativeNameType sanType) {
            this.sanType = sanType;
            this.changedFields = changedFields.add("sanType");
            return this;
        }

        /**
         * <i>“Custom SAN Name”</i>
         * 
         * @param name
         *            value of {@code name} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder name(String name) {
            this.name = name;
            this.changedFields = changedFields.add("name");
            return this;
        }

        public CustomSubjectAlternativeName build() {
            CustomSubjectAlternativeName _x = new CustomSubjectAlternativeName();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.customSubjectAlternativeName";
            _x.sanType = sanType;
            _x.name = name;
            return _x;
        }
    }

    private CustomSubjectAlternativeName _copy() {
        CustomSubjectAlternativeName _x = new CustomSubjectAlternativeName();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.sanType = sanType;
        _x.name = name;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("CustomSubjectAlternativeName[");
        b.append("sanType=");
        b.append(this.sanType);
        b.append(", ");
        b.append("name=");
        b.append(this.name);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/complex/CustomSubjectAlternativeName.java <==
package odata.msgraph.client.beta.complex;

import com.fasterxml.jackson.annotation.JacksonInject;
import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.ODataType;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import odata.msgraph.client.beta.enums.SubjectAlternativeNameType;


/**
 * <i>“Custom Subject Alternative Name definition”</i>
 */@JsonPropertyOrder({
    "@odata.type", 
    "name", 
    "sanType"})
@JsonInclude(Include.NON_NULL)
public class CustomSubjectAlternativeName implements ODataType {

    @JacksonInject
    @JsonIgnore
    protected ContextPath contextPath;

    @JacksonInject
    @JsonIgnore
    protected UnmappedFieldsImpl unmappedFields;

    @JsonProperty("@odata.type")
    protected String odataType;

    @JsonProperty("name")
    protected String name;

    @JsonProperty("sanType")
    protected SubjectAlternativeNameType sanType;

    protected CustomSubjectAlternativeName() {
    }

    @Override
    public String odataTypeName() {
        return "microsoft.graph.customSubjectAlternativeName";
    }

    /**
     * <i>“Custom SAN Name”</i>
     * 
     * @return property name
     */
    @Property(name="name")
    @JsonIgnore
    public Optional<String> getName() {
        return Optional.ofNullable(name);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code name} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“Custom SAN Name”</i>
     * 
     * @param name
     *            new value of {@code name} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code name} field changed
     */
    public CustomSubjectAlternativeName withName(String name) {
        CustomSubjectAlternativeName _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.customSubjectAlternativeName");
        _x.name = name;
        return _x;
    }

    /**
     * <i>“Custom SAN Type.”</i>
     * 
     * @return property sanType
     */
    @Property(name="sanType")
    @JsonIgnore
    public Optional<SubjectAlternativeNameType> getSanType() {
        return Optional.ofNullable(sanType);
    }

    /**
     * Returns an immutable copy of {@code this} with just the {@code sanType} field
     * changed. Field description below. The field name is also added to an internal
     * map of changed fields in the returned object so that when {@code this.patch()}
     * is called (if available)on the returned object only the changed fields are
     * submitted.
     * <p>
     * <i>“Custom SAN Type.”</i>
     * 
     * @param sanType
     *            new value of {@code sanType} field (as defined in service metadata)
     * @return immutable copy of {@code this} with just the {@code sanType} field changed
     */
    public CustomSubjectAlternativeName withSanType(SubjectAlternativeNameType sanType) {
        CustomSubjectAlternativeName _x = _copy();
        _x.odataType = Util.nvl(odataType, "microsoft.graph.customSubjectAlternativeName");
        _x.sanType = sanType;
        return _x;
    }

    public CustomSubjectAlternativeName withUnmappedField(String name, Object value) {
        CustomSubjectAlternativeName _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        // do nothing;
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builder() {
        return new Builder();
    }

    public static final class Builder {
        private String name;
        private SubjectAlternativeNameType sanType;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        /**
         * <i>“Custom SAN Name”</i>
         * 
         * @param name
         *            value of {@code name} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder name(String name) {
            this.name = name;
            this.changedFields = changedFields.add("name");
            return this;
        }

        /**
         * <i>“Custom SAN Type.”</i>
         * 
         * @param sanType
         *            value of {@code sanType} property (as defined in service metadata)
         * @return {@code this} (for method chaining)
         */
        public Builder sanType(SubjectAlternativeNameType sanType) {
            this.sanType = sanType;
            this.changedFields = changedFields.add("sanType");
            return this;
        }

        public CustomSubjectAlternativeName build() {
            CustomSubjectAlternativeName _x = new CustomSubjectAlternativeName();
            _x.contextPath = null;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.customSubjectAlternativeName";
            _x.name = name;
            _x.sanType = sanType;
            return _x;
        }
    }

    private CustomSubjectAlternativeName _copy() {
        CustomSubjectAlternativeName _x = new CustomSubjectAlternativeName();
        _x.contextPath = contextPath;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.name = name;
        _x.sanType = sanType;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("CustomSubjectAlternativeName[");
        b.append("name=");
        b.append(this.name);
        b.append(", ");
        b.append("sanType=");
        b.append(this.sanType);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }

}
